==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/ListQueryKeyBySearchServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group within the current subscription. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property searchServiceName The name of the Azure Cognitive Search service associated with the specified resource group.
 */
public data class ListQueryKeyBySearchServicePlainArgs(
    public val resourceGroupName: String,
    public val searchServiceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs =
        com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .searchServiceName(searchServiceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListQueryKeyBySearchServicePlainArgs].
 */
@PulumiTagMarker
public class ListQueryKeyBySearchServicePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var searchServiceName: String? = null

    /**
     * @param value The name of the resource group within the current subscription. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("rtwsotolhhjvjiru")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Azure Cognitive Search service associated with the specified resource group.
     */
    @JvmName("cpcnxgvmujdsoyfg")
    public suspend fun searchServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.searchServiceName = mapped
    }

    internal fun build(): ListQueryKeyBySearchServicePlainArgs = ListQueryKeyBySearchServicePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        searchServiceName = searchServiceName ?: throw PulumiNullFieldException("searchServiceName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/ListQueryKeyBySearchServicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group within the current subscription. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property searchServiceName The name of the Azure Cognitive Search service associated with the specified resource group.
 */
public data class ListQueryKeyBySearchServicePlainArgs(
    public val resourceGroupName: String,
    public val searchServiceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs =
        com.pulumi.azurenative.search.inputs.ListQueryKeyBySearchServicePlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .searchServiceName(searchServiceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListQueryKeyBySearchServicePlainArgs].
 */
@PulumiTagMarker
public class ListQueryKeyBySearchServicePlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var searchServiceName: String? = null

    /**
     * @param value The name of the resource group within the current subscription. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("bgyvjrjsoickgkwq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Azure Cognitive Search service associated with the specified resource group.
     */
    @JvmName("qkkdhjtnobhbfpcv")
    public suspend fun searchServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.searchServiceName = mapped
    }

    internal fun build(): ListQueryKeyBySearchServicePlainArgs = ListQueryKeyBySearchServicePlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        searchServiceName = searchServiceName ?: throw PulumiNullFieldException("searchServiceName"),
    )
}
